<?php

use Infomaker\Everyware\Base\OpenContent\QueryBuilder;
use Infomaker\Everyware\Base\OpenContent\OpenContentProvider;
use EuKit\Base\Parts\NewsMLArticle;
use EuKit\Base\ViewModels\Teaser;
use Infomaker\Everyware\Twig\View;

add_action( 'wp_ajax_fetch_concept_posts', 'ajax_fetch_concept_posts' );
add_action( 'wp_ajax_nopriv_fetch_concept_posts', 'ajax_fetch_concept_posts' );

function ajax_fetch_concept_posts(): void
{
    $data = $_REQUEST['data'];
    $uuid = sanitize_text_field($data['uuid']);
    $start = (int)$data['start'];

    $query = QueryBuilder::where('ConceptUuids', $uuid)->andIfProperty('Status', 'usable');
    $limit = 20;
    $provider = OpenContentProvider::setup([
        'q'                      => $query->buildQueryString(),
        'contenttypes'           => ['Article'],
        'sort.indexfield'        => 'Pubdate',
        'sort.Pubdate.ascending' => 'false',
        'limit'                  => $limit + 1,
        'start'                  => $start,
    ]);

    $articles = $provider->queryWithRequirements();
    $views = [];

    if (is_array($articles)) {
        foreach ($articles as $key => $article) {
            ob_start();
            if ($article instanceof OcArticle) {
                $newsmlArticle = NewsMLArticle::createfromOcObject($article);
                $teaser = new Teaser($newsmlArticle);
                View::render('@base/page/concept-post-small', array('article' => $teaser->getViewData()));
            }
            $views[] = ob_get_clean();
        }
    }

    $all_articles_loaded = (count($views) > $limit) ? false : true;

    if(!$all_articles_loaded) {
        array_pop($views);
    }

    $result = array(
        'articles' => $views,
        'all_articles_loaded' => $all_articles_loaded,
    );

    echo json_encode($result);
    wp_die();
}
