<?php

use EuKit\Base\Parts\Concept;
use EuKit\Base\ViewModels\Teaser;
use Infomaker\Everyware\Twig\View;
use EuKit\Base\Parts\NewsMLArticle;
use EuKit\Base\ViewModels\ConceptPage;
use Infomaker\Everyware\Base\Models\Page;
use Infomaker\Everyware\Base\OpenContent\QueryBuilder;
use Infomaker\Everyware\Base\OpenContent\OpenContentProvider;

$current_page = Page::current();

if ($current_page instanceof Page) {
    $concept = Concept::createFromPost($current_page);
    $conceptPage = new ConceptPage($concept);
    $uuid = $conceptPage->getViewData()['uuid'];
    $query = QueryBuilder::where('ConceptUuids', $uuid)->andIfProperty('Status', 'usable');
    $limit = 14;
    $provider = OpenContentProvider::setup([
        'q'                      => $query->buildQueryString(),
        'contenttypes'           => ['Article'],
        'sort.indexfield'        => 'Pubdate',
        'sort.Pubdate.ascending' => 'false',
        'limit'                  => $limit + 1,
        'start'                  => 0,
    ]);

    $articles = $provider->queryWithRequirements();
    $teasers = [];

    if (is_array($articles)) {
        foreach ($articles as $key => $article) {
            if ($article instanceof OcArticle) {
                $newsmlArticle = NewsMLArticle::createfromOcObject($article);
                $teaser = new Teaser($newsmlArticle);

                $teasers[] = $teaser->getViewData();
            }
        }
    }

    $all_articles_loaded = (count($teasers) > $limit) ? false : true;
    if (!$all_articles_loaded) {
        array_pop($teasers);
    }

    $conceptPage->setViewData('articles', $teasers);

    View::render('@base/page/concept-page', array_merge($conceptPage->getViewData(), array('all_articles_loaded' => $all_articles_loaded)));
}
